pub struct SystemClock;Expand description
SystemClock implementation using the system time. Returns the current time in nanoseconds since the Unix epoch. Panics if the system clock is before the Unix epoch. This is the default clock used in the RateLimiter. Implements the Clock trait. Thread-safe and can be shared across threads.